@@ -30,11 +30,12 @@
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
  */
 
-#ifndef IPMI_STRINGS_H
-#define IPMI_STRINGS_H
+#pragma once
 
 #include <ipmitool/helper.h>
 
+#define CC_STRING(cc) val2str(cc, completion_code_vals)
+
 extern const struct valstr completion_code_vals[];
 extern const struct valstr entity_id_vals[];
 extern const struct valstr entity_device_type_vals[];
@@ -48,10 +49,14 @@ extern const struct valstr ipmi_authtype_vals[];
 extern const struct valstr ipmi_channel_protocol_vals[];
 extern const struct valstr ipmi_channel_medium_vals[];
 extern const struct valstr ipmi_chassis_power_control_vals[];
+extern const struct valstr ipmi_chassis_restart_cause_vals[];
 extern const struct valstr ipmi_auth_algorithms[];
 extern const struct valstr ipmi_integrity_algorithms[];
 extern const struct valstr ipmi_encryption_algorithms[];
-extern const struct valstr ipmi_oem_info[];
+extern const struct valstr ipmi_user_enable_status_vals[];
+extern const struct valstr *ipmi_oem_info;
+int ipmi_oem_info_init();
+void ipmi_oem_info_free();
 
 extern const struct valstr picmg_frucontrol_vals[];
 extern const struct valstr picmg_clk_family_vals[];
@@ -68,8 +73,5 @@ extern const struct oemvalstr picmg_busres_shmc_status_vals[];
 /* these are similar, expect that the lookup takes the IANA number
    as first parameter */
 extern const struct oemvalstr ipmi_oem_product_info[];
-extern const struct oemvalstr ipmi_oem_sdr_type_vals[];
-
-
-
-#endif /*IPMI_STRINGS_H*/
+extern const char *ipmi_generic_sensor_type_vals[];
+extern const struct oemvalstr ipmi_oem_sensor_type_vals[];
