@@ -96,7 +96,7 @@ void lperror(int level, const char * format, ...)
 	return;
 }
 
-/* 
+/*
  * open connection to syslog if daemon
  */
 void log_init(const char * name, int isdaemon, int verbose)
@@ -108,14 +108,14 @@ void log_init(const char * name, int isdaemon, int verbose)
 	if (!logpriv)
 		return;
 
-	if (name != NULL)
+	if (name)
 		logpriv->name = strdup(name);
 	else
 		logpriv->name = strdup(LOG_NAME_DEFAULT);
 
-	if (logpriv->name == NULL)
+	if (!logpriv->name)
 		fprintf(stderr, "ipmitool: malloc failure\n");
-	
+
 	logpriv->daemon = isdaemon;
 	logpriv->level = verbose + LOG_NOTICE;
 
@@ -144,13 +144,8 @@ void log_halt(void)
 	logpriv = NULL;
 }
 
-int log_level_get(void)
+void log_level_set(int verbose)
 {
-	return logpriv->level;
-}
-
-void log_level_set(int level)
-{
-	logpriv->level = level;
+	logpriv->level = verbose + LOG_NOTICE;
 }
 
